#! /usr/bin/env bash

function test_bluer_sandbox_arvancloud_seed_one() {
    local options=$1

    bluer_ai_eval ,$options \
        "bluer_ai_seed arvancloud screen"
}

function test_bluer_sandbox_arvancloud_seed_two() {
    local options=$1

    bluer_ai_eval ,$options \
        "bluer_sandbox_arvancloud seed screen"
}
